@@ -1,3 +1,3 @@
 """Factories for randomised AFL data sets for testing purposes."""
 
-from .fixtures import generate_fixtures
+from .data_factory import CandyStore
